{****************************************************************
 *
 * Unit Name: WordCaptureUnit
 * Purpose  : To capture any word on screen..
 * Author   : Sang-Hee, Kim
 * Date     : 98-08-12
 * History  : V1.0.  98-08-12     First Release
 *            V1.1   98-08-13     Modified in init procedure
 *
 ****************************************************************}

Unit WordCaptureUnit;

Interface

Uses Windows, Messages;

Const
    DLLName = 'WCModule.DLL';

Function DLLLoad: Boolean;
Function DLLUnload: Boolean;
Function DLLLoaded: Boolean;
Function StartCapture: Boolean;
Function StopCapture: Boolean;
Function CaptureWord(W: PChar; MaxLen: Word): Boolean;
Procedure ForceInit;

Var
    WCModule_ForceInit: Boolean = False;

Implementation

Type
    THookInit = Procedure; stdcall;
    THookOp = Function: Boolean; stdcall;
    THookCap = Procedure; stdcall;
    THookGet = Procedure(W: PChar; MaxLen: Word); Stdcall;

Var
    DLLHandle: THandle = 0;
    Finished: Boolean = False;
    MSG_CAPTURE: Integer = 0;
    HWND_MsgWindow: HWND = 0;

    proc_Init, proc_ForceInit: THookInit;
    proc_StartCapture, proc_StopCapture: THookOp;
    proc_CaptureWord: THookGet;


(****************************************************************************
 *  ProcName  : DLLLoad
 *  Purpose   : Loading DLL
 *  Comment   : You must call this 'DLLLoad' FIRST to activate.
 ****************************************************************************)

Function DLLLoad: Boolean;
Begin
    Result := False;

    DllHandle := 0;

    If GetModuleHandle(DLLName) <> 0 Then Exit;

    DllHandle := LoadLibrary(DLLName);
    Finished := False;
    If DLLHandle = 0 Then Exit;

    proc_StartCapture := GetProcAddress(DllHandle, 'StartCapturing');
    proc_StopCapture := GetProcAddress(DllHandle, 'StopCapturing');
    proc_CaptureWord := GetProcAddress(DllHandle, 'CaptureWord');
    proc_Init := GetProcAddress(DllHandle, 'InitCapturing');
    proc_ForceInit := GetProcAddress(DllHandle, 'ReInit');

    If WCModule_ForceInit Then Begin
        WCModule_ForceInit := False;
        proc_Init;
    End;

    Result := True;
End;


(****************************************************************************
 *  ProcName  : DLLUnload
 *  Purpose   : Unloading DLL
 *  Comment   : You must call this 'DLLUnload' LAST before close your app.
 ****************************************************************************)

Function DLLUnload: Boolean;
Begin
    Result := False;

    If Not Finished Then
        If Not StopCapture Then Exit;

    Result := FreeLibrary(DLLHandle);
End;


(****************************************************************************
 *  ProcName  : DLLLoaded
 *  Purpose   : Return boolean value whether dll module is loaded.
 *  Comment   :
 ****************************************************************************)

Function DLLLoaded: Boolean;
Begin
    Result := (DLLHandle <> 0);
End;


(****************************************************************************
 *  ProcName  : StartCapture
 *  Purpose   : Activate Word Capture
 *  Comment   :
 ****************************************************************************)

Function StartCapture: Boolean;
Begin
    Result := False;
    If (DllHandle = 0) Or (Finished) Then Exit;

    proc_StartCapture;
    Finished := False;
    Result := True;
End;


(****************************************************************************
 *  ProcName  : StopCapture
 *  Purpose   : De-activate Word Capture
 *  Comment   :
 ****************************************************************************)

Function StopCapture: Boolean;
Begin
    Result := False;
    If (DllHandle = 0) Or (Finished) Then Exit;

    proc_StopCapture;
    Finished := True;
    Result := True;
End;


(****************************************************************************
 *  ProcName  : CaptureWord
 *  Purpose   : Get a word from current mouse position.
 *  Comment   :
 ****************************************************************************)

Function CaptureWord(W: PChar; MaxLen: Word): Boolean;
Begin
    Result := False;
    If (DllHandle = 0) Or (Finished) Then Exit;

    proc_CaptureWord(W, MaxLen);
    Result := True;
End;


(****************************************************************************
 *  ProcName  : ForceInit
 *  Purpose   : Reinitialize
 *  Comment   :
 ****************************************************************************)
Procedure ForceInit;
Begin
    proc_ForceInit;
End;


End.

